@@ -1,8 +1,9 @@
-use strict;
-use warnings;
 
 package String::Interpolate;
-our $VERSION = 0.3;
+$String::Interpolate::VERSION = '0.31';
+use 5.006;
+use strict;
+use warnings;
 use Carp qw( croak );
 
 =head1 NAME
@@ -10,7 +11,7 @@ use Carp qw( croak );
 String::Interpolate - Wrapper for builtin the Perl interpolation engine.
 
 =head1 SYNOPSIS
-    
+
     # Functional interface
     use String::Interpolate qw( safe_interpolate interpolate ); 
     our($GREET) = 'Hello'; # Cannot be lexical 
@@ -750,8 +751,6 @@ sub unsafe_symbols {
     $self;
 }
 
-=over 4
-
 =item lexicals
 
 This feature is EXPERIMENTAL.  Do not use it in real code.
@@ -973,7 +972,7 @@ sub ashash {
 }
  
 package String::Interpolate::AsArray;
-
+$String::Interpolate::AsArray::VERSION = '0.31';
 sub TIEARRAY { my ($class, $thing ) = @_; bless \$thing, $class }
 
 sub STORE { ${${$_[0]}}->{pos}[$_[1]-1]=$_[2] }
@@ -988,7 +987,7 @@ sub FETCH {
 # A private and very secretive class to give secure access to an object
 
 package String::Interpolate::Func;
-
+$String::Interpolate::Func::VERSION = '0.31';
 sub wrap_hash {
     my $class = shift;
     my ($k,$v) = @_;
@@ -1029,4 +1028,24 @@ sub AUTOLOAD {
 
 1;
 __END__
+
 =back
+
+=head1 REPOSITORY
+
+L<https://github.com/neilbowers/String-Interpolate>
+
+=head1 AUTHOR
+
+Created by Brian McCauley,
+currently maintained by Neil Bowers E<lt>neilb@cpan.orgE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2002 by Brian McCauley.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
